# `royalnet_telethon`

A Telethon-based PDA implementation for the `royalnet.engineer` module.

The documentation is [hosted on Read The Docs](https://royalnet-console.readthedocs.io/en/latest/).

## See also

- [Royalnet 6](https://github.com/Steffo99/royalnet-6)
